@@ -67,7 +67,7 @@ class Pane(util.TmuxMappingObject, util.TmuxRelationalObject):
         :rtype: :class:`Server.tmux`
 
         """
-        if not len([arg for arg in args if '-t' in arg]):
+        if not any(arg.startswith('-t') for arg in args):
             args = ('-t', self.get('pane_id')) + args
 
         return self.server.tmux(cmd, *args, **kwargs)
