@@ -9,7 +9,6 @@ from __future__ import absolute_import, division, print_function, \
     with_statement, unicode_literals
 
 import os
-import pipes
 import logging
 
 from .window import Window
@@ -108,7 +107,6 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
         :rtype: :class:`Session`
 
         """
-        new_name = pipes.quote(new_name)
         proc = self.tmux(
             'rename-session',
             '-t%s' % self.get('session_id'),
@@ -164,7 +162,6 @@ class Session(util.TmuxMappingObject, util.TmuxRelationalObject):
         if start_directory:
             # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-window -c.
             start_directory = os.path.expanduser(start_directory)
-            start_directory = pipes.quote(start_directory)
             window_args += ('-c%s' % start_directory,)
 
         window_args += (
