@@ -358,6 +358,9 @@ class BlankPaneTest(TmuxTestCase):
         )
         self.assertEqual(len(window3._panes), 3)
 
+        window4 = self.session.findWhere({'window_name': 'Blank with options'})
+        self.assertEqual(len(window4._panes), 2)
+
 
 class StartDirectoryTest(TmuxTestCase):
     yaml_config = """
@@ -384,6 +387,16 @@ class StartDirectoryTest(TmuxTestCase):
         - echo "hey"
       - shell_command:
         - echo "moo"
+    - window_name: cwd containing a space
+      start_directory: /tmp/foo bar
+      layout: main-horizontal
+      panes:
+      - shell_command:
+        - pwd
+      - shell_command:
+        - echo "hey"
+      - shell_command:
+        - echo "moo"
     - window_name: testsa3
       layout: main-horizontal
       panes:
@@ -405,6 +418,19 @@ class StartDirectoryTest(TmuxTestCase):
         - echo "moo3"
     """
 
+    def setUp(self):
+        super(StartDirectoryTest, self).setUp()
+        if not os.path.exists('/tmp/foo bar'):
+            os.mkdir('/tmp/foo bar')
+            self._temp_dir_created = True
+        else:
+            self._temp_dir_created = False
+
+    def tearDown(self):
+        super(StartDirectoryTest, self).tearDown()
+        if self._temp_dir_created:
+            os.rmdir('/tmp/foo bar')
+
     def test_start_directory(self):
 
         sconfig = kaptan.Kaptan(handler='yaml')
@@ -416,10 +442,16 @@ class StartDirectoryTest(TmuxTestCase):
         builder.build(session=self.session)
 
         assert(self.session == builder.session)
-        for path in ['/usr/bin', '/dev/', '/usr/', os.getcwd()]:
-            for window in self.session.windows:
-                for p in window.panes:
-                    self.assertTrue(p.get('pane_start_path', path))
+        dirs = ['/usr/bin', '/dev', '/tmp/foo bar', '/usr', os.getcwd()]
+        for path, window in zip(dirs, self.session.windows):
+            for p in window.panes:
+                for i in range(60):
+                    p.server._update_panes()
+                    if p.get('pane_current_path') == path:
+                        break
+                    time.sleep(.2)
+
+                self.assertEqual(p.get('pane_current_path'), path)
 
 
 class PaneOrderingTest(TmuxTestCase):
